var l=Object.defineProperty;var u=(a,e,r)=>e in a?l(a,e,{enumerable:!0,configurable:!0,writable:!0,value:r}):a[e]=r;var i=(a,e,r)=>(u(a,typeof e!="symbol"?e+"":e,r),r);import{m as p,C as _,e as f,R as d,f as v}from"./index-FcXwFJdn.js";var h=Object.defineProperty,C=Object.getOwnPropertyDescriptor,n=(a,e,r,s)=>{for(var t=s>1?void 0:s?C(e,r):e,m=a.length-1,c;m>=0;m--)(c=a[m])&&(t=(s?c(e,r,t):c(t))||t);return s&&t&&h(e,r,t),t};let o=class extends p(_){constructor(){super(...arguments);i(this,"cameraVideo");i(this,"cameraVideoSource","")}startPlayback(){const r=this.buildAbsoluteUrl(this.camera.urlStream||"").toString();this.cameraVideoSource=r,this.$emit("raw-camera-url",r)}stopPlayback(){this.cameraVideoSource="",this.cameraVideo.src=""}};n([d("streamingElement")],o.prototype,"cameraVideo",2);o=n([f({})],o);var P=function(){var e=this,r=e._self._c;return e._self._setupProxy,r("video",{ref:"streamingElement",style:e.cameraStyle,attrs:{src:e.cameraVideoSource,autoplay:"",muted:"",crossorigin:e.crossorigin},domProps:{muted:!0}})},y=[],S=v(o,P,y,!1,null,null,null,null);const g=S.exports;export{g as default};
