var m=Object.defineProperty;var _=(r,e,a)=>e in r?m(r,e,{enumerable:!0,configurable:!0,writable:!0,value:a}):r[e]=a;var l=(r,e,a)=>(_(r,typeof e!="symbol"?e+"":e,a),a);import{m as p,C as v,e as f,R as u,f as d}from"./index-FcXwFJdn.js";var y=Object.defineProperty,C=Object.getOwnPropertyDescriptor,c=(r,e,a,s)=>{for(var t=s>1?void 0:s?C(e,a):e,o=r.length-1,i;o>=0;o--)(i=r[o])&&(t=(s?i(e,a,t):i(t))||t);return s&&t&&y(e,a,t),t};let n=class extends p(v){constructor(){super(...arguments);l(this,"cameraVideo")}startPlayback(){navigator.mediaDevices.getUserMedia({video:!0}).then(a=>this.cameraVideo.srcObject=a).then(()=>this.$emit("playback"))}stopPlayback(){this.cameraVideo.srcObject=null}};c([u("streamingElement")],n.prototype,"cameraVideo",2);n=c([f({})],n);var P=function(){var e=this,a=e._self._c;return e._self._setupProxy,a("video",{ref:"streamingElement",style:e.cameraStyle,attrs:{autoplay:"",muted:""},domProps:{muted:!0}})},b=[],h=d(n,P,b,!1,null,null,null,null);const g=h.exports;export{g as default};
