const a="text.log",e=["log"],n="Log file",t=[{match:"\\b(DEBUG|Debug|Trace)\\b|(?i)\\b(debug)\\:",name:"markup.changed"},{match:"(?i)\\[(debug|dbug|dbg|de|d)\\]",name:"markup.changed"},{match:"\\b(HINT|INFO|INFORMATION|Info|NOTICE)\\b|(?i)\\b(info|information)\\:",name:"markup.inserted"},{match:"(?i)\\[(information|info|inf|in|i)\\]",name:"markup.inserted"},{match:"\\b(WARNING|WARN|Warn)\\b|(?i)\\b(warning)\\:",name:"markup.deleted"},{match:"(?i)\\[(warning|warn|wrn|wn|w)\\]",name:"markup.deleted"},{match:"\\b(ALERT|CRITICAL|EMERGENCY|ERROR|FAILURE|FAIL|Fatal|Error)\\b|(?i)\\b(error)\\:",name:"string.regexp"},{match:"(?i)\\[(error|eror|err|er|e|fatal|fatl|ftl|fa|f)\\]",name:"string.regexp"},{match:"\\b\\d{4}-\\d{2}-\\d{2}(T|\\b)",name:"comment"},{match:"\\b\\d{2}[^\\w\\s]\\d{2}[^\\w\\s]\\d{4}\\b",name:"comment"},{match:"\\d{2}:\\d{2}(:\\d{2}([.,]\\d{3,})?)?(Z| ?[+-]\\d{2}:\\d{2})?\\b",name:"comment"},{match:"\\b([0-9a-fA-F]{40}|[0-9a-fA-F]{10}|[0-9a-fA-F]{7})\\b",name:"constant.language"},{match:"[0-9a-fA-F]{8}[-]?([0-9a-fA-F]{4}[-]?){3}[0-9a-fA-F]{12}",name:"constant.language"},{match:"\\b([0-9]+|true|false|null)\\b",name:"constant.language"},{match:'"[^"]*"',name:"string"},{match:"(^|[^\\w])'[^']*'",name:"string"},{match:"\\b([a-zA-Z.]*Exception)\\b",name:"string.regexp, emphasis"},{begin:"^[\\t ]*at",end:"$",name:"string.key, emphasis"},{match:"\\b(http|https|ftp|file)://\\S+\\b/?",name:"constant.language"},{match:"\\b([\\w-]+\\.)+([\\w-])+\\b",name:"constant.language"}],m={scopeName:a,fileTypes:e,name:n,patterns:t};export{m as default,e as fileTypes,n as name,t as patterns,a as scopeName};
