var i=Object.defineProperty;var u=(a,e,r)=>e in a?i(a,e,{enumerable:!0,configurable:!0,writable:!0,value:r}):a[e]=r;var o=(a,e,r)=>(u(a,typeof e!="symbol"?e+"":e,r),r);import{m as _,C as g,e as p,R as f,f as h}from"./index-FcXwFJdn.js";var v=Object.defineProperty,S=Object.getOwnPropertyDescriptor,l=(a,e,r,t)=>{for(var s=t>1?void 0:t?S(e,r):e,c=a.length-1,n;c>=0;c--)(n=a[c])&&(s=(t?n(e,r,s):n(s))||s);return t&&s&&v(e,r,s),s};let m=class extends _(g){constructor(){super(...arguments);o(this,"cameraImage");o(this,"cameraImageSource","")}startPlayback(){const r=this.buildAbsoluteUrl(this.camera.urlStream||"");r.searchParams.set("cacheBust",Date.now().toString()),this.cameraImageSource=r.toString(),this.$emit("raw-camera-url",this.cameraImageSource)}stopPlayback(){this.cameraImageSource="",this.cameraImage.src=""}};l([f("streamingElement")],m.prototype,"cameraImage",2);m=l([p({})],m);var C=function(){var e=this,r=e._self._c;return e._self._setupProxy,r("img",{ref:"streamingElement",style:e.cameraStyle,attrs:{src:e.cameraImageSource,crossorigin:e.crossorigin}})},I=[],P=h(m,C,I,!1,null,null,null,null);const j=P.exports;export{j as default};
